@@ -47,7 +47,6 @@
 #include <cstdint>
 #include <map>
 #include <unordered_map>
-#include <vector>
 
 namespace llvm {
 class IntrinsicInst;
@@ -55,7 +54,6 @@ class IntrinsicInst;
 
 namespace SPIRV {
 
-/// SPIR-V versions known to translator.
 enum class VersionNumber : uint32_t {
   // See section 2.3 of SPIR-V spec: Physical Layout of a SPIR_V Module and
   // Instruction
@@ -64,33 +62,12 @@ enum class VersionNumber : uint32_t {
   SPIRV_1_2 = 0x00010200,
   SPIRV_1_3 = 0x00010300,
   SPIRV_1_4 = 0x00010400,
-  SPIRV_1_5 = 0x00010500,
-  SPIRV_1_6 = 0x00010600,
+  // TODO: populate this enum with the latest versions (up to 1.5) once
+  // translator get support of corresponding features
   MinimumVersion = SPIRV_1_0,
-  MaximumVersion = SPIRV_1_6
+  MaximumVersion = SPIRV_1_4
 };
 
-inline std::string formatVersionNumber(uint32_t Version) {
-  switch (Version) {
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_0):
-    return "1.0";
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_1):
-    return "1.1";
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_2):
-    return "1.2";
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_3):
-    return "1.3";
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_4):
-    return "1.4";
-  }
-  return "unknown";
-}
-
-inline bool isSPIRVVersionKnown(uint32_t Ver) {
-  return Ver >= static_cast<uint32_t>(VersionNumber::MinimumVersion) &&
-         Ver <= static_cast<uint32_t>(VersionNumber::MaximumVersion);
-}
-
 enum class ExtensionID : uint32_t {
   First,
 #define EXT(X) X,
@@ -103,21 +80,12 @@ enum class BIsRepresentation : uint32_t { OpenCL12, OpenCL20, SPIRVFriendlyIR };
 
 enum class FPContractMode : uint32_t { On, Off, Fast };
 
-enum class DebugInfoEIS : uint32_t {
-  SPIRV_Debug,
-  OpenCL_DebugInfo_100,
-  NonSemantic_Shader_DebugInfo_100,
-  NonSemantic_Shader_DebugInfo_200
-};
-
-enum class BuiltinFormat : uint32_t { Function, Global };
+enum class DebugInfoEIS : uint32_t { SPIRV_Debug, OpenCL_DebugInfo_100 };
 
 /// \brief Helper class to manage SPIR-V translation
 class TranslatorOpts {
 public:
-  // Unset optional means not directly specified by user
-  using ExtensionsStatusMap = std::map<ExtensionID, llvm::Optional<bool>>;
-
+  using ExtensionsStatusMap = std::map<ExtensionID, bool>;
   using ArgList = llvm::SmallVector<llvm::StringRef, 4>;
 
   TranslatorOpts() = default;
@@ -134,14 +102,7 @@ public:
     if (ExtStatusMap.end() == I)
       return false;
 
-    return I->second && *I->second;
-  }
-
-  void setAllowedToUseExtension(ExtensionID Extension, bool Allow = true) {
-    // Only allow using the extension if it has not already been disabled
-    auto I = ExtStatusMap.find(Extension);
-    if (I == ExtStatusMap.end() || !I->second || (*I->second) == true)
-      ExtStatusMap[Extension] = Allow;
+    return I->second;
   }
 
   VersionNumber getMaxVersion() const { return MaxVersion; }
@@ -152,10 +113,6 @@ public:
 
   void setMemToRegEnabled(bool Mem2Reg) { SPIRVMemToReg = Mem2Reg; }
 
-  bool preserveAuxData() const { return PreserveAuxData; }
-
-  void setPreserveAuxData(bool ArgValue) { PreserveAuxData = ArgValue; }
-
   void setGenKernelArgNameMDEnabled(bool ArgNameMD) {
     GenKernelArgNameMD = ArgNameMD;
   }
@@ -224,63 +181,6 @@ public:
     PreserveOCLKernelArgTypeMetadataThroughString = Value;
   }
 
-  bool shouldEmitFunctionPtrAddrSpace() const noexcept {
-    return EmitFunctionPtrAddrSpace;
-  }
-
-  void setEmitFunctionPtrAddrSpace(bool Value) noexcept {
-    EmitFunctionPtrAddrSpace = Value;
-  }
-
-  void setBuiltinFormat(BuiltinFormat Value) noexcept {
-    SPIRVBuiltinFormat = Value;
-  }
-  BuiltinFormat getBuiltinFormat() const noexcept { return SPIRVBuiltinFormat; }
-
-  void setFnVarCategory(uint32_t Category) noexcept {
-    FnVarCategory = Category;
-  }
-  llvm::Optional<uint32_t> getFnVarCategory() const noexcept {
-    return FnVarCategory;
-  }
-
-  void setFnVarFamily(uint32_t Family) noexcept { FnVarFamily = Family; }
-  llvm::Optional<uint32_t> getFnVarFamily() const noexcept {
-    return FnVarFamily;
-  }
-
-  void setFnVarArch(uint32_t Arch) noexcept { FnVarArch = Arch; }
-  llvm::Optional<uint32_t> getFnVarArch() const noexcept { return FnVarArch; }
-
-  void setFnVarTarget(uint32_t Target) noexcept { FnVarTarget = Target; }
-  llvm::Optional<uint32_t> getFnVarTarget() const noexcept {
-    return FnVarTarget;
-  }
-
-  void setFnVarFeatures(std::vector<uint32_t> Features) noexcept {
-    FnVarFeatures = Features;
-  }
-  std::vector<uint32_t> getFnVarFeatures() const noexcept {
-    return FnVarFeatures;
-  }
-
-  void setFnVarCapabilities(std::vector<uint32_t> Capabilities) noexcept {
-    FnVarCapabilities = Capabilities;
-  }
-  std::vector<uint32_t> getFnVarCapabilities() const noexcept {
-    return FnVarCapabilities;
-  }
-
-  void setFnVarSpecEnable(bool Val) noexcept { FnVarSpecEnable = Val; }
-  bool getFnVarSpecEnable() const noexcept { return FnVarSpecEnable; }
-
-  void setFnVarSpvOut(std::string Val) noexcept { FnVarSpvOut = Val; }
-  std::string getFnVarSpvOut() const noexcept { return FnVarSpvOut; }
-
-  // Check that options passed to --fnvar-xxx flags make sense. Return true on
-  // success, false on failure.
-  bool validateFnVarOpts() const;
-
 private:
   // Common translation options
   VersionNumber MaxVersion = VersionNumber::MaximumVersion;
@@ -321,23 +221,6 @@ private:
   // Add a workaround to preserve OpenCL kernel_arg_type and
   // kernel_arg_type_qual metadata through OpString
   bool PreserveOCLKernelArgTypeMetadataThroughString = false;
-
-  // Controls if CodeSectionINTEL can be emitted and consumed with a dedicated
-  // address space
-  bool EmitFunctionPtrAddrSpace = false;
-
-  bool PreserveAuxData = false;
-
-  llvm::Optional<uint32_t> FnVarCategory;
-  llvm::Optional<uint32_t> FnVarFamily;
-  llvm::Optional<uint32_t> FnVarArch;
-  llvm::Optional<uint32_t> FnVarTarget;
-  std::vector<uint32_t> FnVarFeatures = {};
-  std::vector<uint32_t> FnVarCapabilities = {};
-  std::string FnVarSpvOut = "";
-  bool FnVarSpecEnable = false;
-
-  BuiltinFormat SPIRVBuiltinFormat = BuiltinFormat::Function;
 };
 
 } // namespace SPIRV
