@@ -328,9 +328,7 @@ void OCLToSPIRVBase::visitCallInst(CallInst &CI) {
     return;
   }
   if (DemangledName == kOCLBuiltinName::Dot ||
-      DemangledName == kOCLBuiltinName::DotAccSat ||
-      DemangledName.startswith(kOCLBuiltinName::Dot4x8PackedPrefix) ||
-      DemangledName.startswith(kOCLBuiltinName::DotAccSat4x8PackedPrefix)) {
+      DemangledName == kOCLBuiltinName::DotAccSat) {
     if (CI.getOperand(0)->getType()->isVectorTy()) {
       auto *VT = (VectorType *)(CI.getOperand(0)->getType());
       if (!isa<llvm::IntegerType>(VT->getElementType())) {
@@ -341,10 +339,6 @@ void OCLToSPIRVBase::visitCallInst(CallInst &CI) {
     visitCallDot(&CI, MangledName, DemangledName);
     return;
   }
-  if (DemangledName.startswith(kOCLBuiltinName::ClockReadPrefix)) {
-    visitCallClockRead(&CI, MangledName, DemangledName);
-    return;
-  }
   if (DemangledName == kOCLBuiltinName::FMin ||
       DemangledName == kOCLBuiltinName::FMax ||
       DemangledName == kOCLBuiltinName::Min ||
@@ -385,10 +379,6 @@ void OCLToSPIRVBase::visitCallInst(CallInst &CI) {
     visitSubgroupImageMediaBlockINTEL(&CI, DemangledName);
     return;
   }
-  if (DemangledName.find(kOCLBuiltinName::SplitBarrierINTELPrefix) == 0) {
-    visitCallSplitBarrierINTEL(&CI, DemangledName);
-    return;
-  }
   // Handle 'cl_intel_device_side_avc_motion_estimation' extension built-ins
   if (DemangledName.find(kOCLSubgroupsAVCIntel::Prefix) == 0 ||
       // Workaround for a bug in the extension specification
@@ -497,23 +487,8 @@ CallInst *OCLToSPIRVBase::visitCallAtomicCmpXchg(CallInst *CI) {
   mutateCallInstOCL(
       M, CI,
       [&](CallInst *CI, std::vector<Value *> &Args, Type *&RetTy) {
-        RetTy = Args[2]->getType();
-        if (RetTy->isFloatTy() || RetTy->isDoubleTy()) {
-          RetTy = RetTy->isFloatTy() ? Type::getInt32Ty(*Ctx)
-                                     : Type::getInt64Ty(*Ctx);
-          Args[0] = new BitCastInst(
-              Args[0],
-              PointerType::get(RetTy,
-                               Args[0]->getType()->getPointerAddressSpace()),
-              "", CI);
-          Args[1] = new BitCastInst(
-              Args[1],
-              PointerType::get(RetTy,
-                               Args[1]->getType()->getPointerAddressSpace()),
-              "", CI);
-          Args[2] = new BitCastInst(Args[2], RetTy, "", CI);
-        }
         Expected = Args[1]; // temporary save second argument.
+        RetTy = Args[2]->getType();
         Args[1] = new LoadInst(RetTy, Args[1], "exp", false, CI);
         assert(Args[1]->getType()->isIntegerTy() &&
                Args[2]->getType()->isIntegerTy() &&
@@ -1348,11 +1323,19 @@ void OCLToSPIRVBase::visitCallDot(CallInst *CI, StringRef MangledName,
   // translation for dot function calls,
   // to differentiate between integer dot products
 
+  SmallVector<Value *, 3> Args;
+  Args.push_back(CI->getOperand(0));
+  Args.push_back(CI->getOperand(1));
   bool IsFirstSigned, IsSecondSigned;
   bool IsDot = DemangledName == kOCLBuiltinName::Dot;
-  bool IsAccSat = DemangledName.contains(kOCLBuiltinName::DotAccSat);
-  bool IsPacked = CI->getOperand(0)->getType()->isIntegerTy();
-  if (!IsPacked) {
+  std::string FunName = (IsDot) ? "DotKHR" : "DotAccSatKHR";
+  if (CI->arg_size() > 2) {
+    Args.push_back(CI->getOperand(2));
+  }
+  if (CI->arg_size() > 3) {
+    Args.push_back(CI->getOperand(3));
+  }
+  if (CI->getOperand(0)->getType()->isVectorTy()) {
     if (IsDot) {
       // dot(char4, char4) _Z3dotDv4_cS_
       // dot(char4, uchar4) _Z3dotDv4_cDv4_h
@@ -1393,28 +1376,21 @@ void OCLToSPIRVBase::visitCallDot(CallInst *CI, StringRef MangledName,
     }
   } else {
     // for packed format
-    // dot_4x8packed_ss_int(uint, uint) _Z20dot_4x8packed_ss_intjj
-    // dot_4x8packed_su_int(uint, uint) _Z20dot_4x8packed_su_intjj
-    // dot_4x8packed_us_int(uint, uint) _Z20dot_4x8packed_us_intjj
-    // dot_4x8packed_uu_uint(uint, uint) _Z21dot_4x8packed_uu_uintjj
+    // dot(int, int, int) _Z3dotiii
+    // dot(int, uint, int) _Z3dotiji
+    // dot(uint, int, int) _Z3dotjii
+    // dot(uint, uint, int) _Z3dotjji
     // or
-    // dot_acc_sat_4x8packed_ss_int(uint, uint, int)
-    // _Z28dot_acc_sat_4x8packed_ss_intjji
-    // dot_acc_sat_4x8packed_su_int(uint, uint, int)
-    // _Z28dot_acc_sat_4x8packed_su_intjji
-    // dot_acc_sat_4x8packed_us_int(uint, uint, int)
-    // _Z28dot_acc_sat_4x8packed_us_intjji
-    // dot_acc_sat_4x8packed_uu_uint(uint, uint, uint)
-    // _Z29dot_acc_sat_4x8packed_uu_uintjjj
-    assert(MangledName.startswith("_Z20dot_4x8packed") ||
-           MangledName.startswith("_Z21dot_4x8packed") ||
-           MangledName.startswith("_Z28dot_acc_sat_4x8packed") ||
-           MangledName.startswith("_Z29dot_acc_sat_4x8packed"));
-    size_t SignIndex = IsAccSat
-                           ? strlen(kOCLBuiltinName::DotAccSat4x8PackedPrefix)
-                           : strlen(kOCLBuiltinName::Dot4x8PackedPrefix);
-    IsFirstSigned = DemangledName[SignIndex] == 's';
-    IsSecondSigned = DemangledName[SignIndex + 1] == 's';
+    // dot_acc_sat(int, int, int, int) _Z11dot_acc_satiiii
+    // dot_acc_sat(int, uint, int, int) _Z11dot_acc_satijii
+    // dot_acc_sat(uint, int, int, int) _Z11dot_acc_satjiii
+    // dot_acc_sat(uint, uint, int, int) _Z11dot_acc_satjjii
+    assert(MangledName.startswith("_Z3dot") ||
+           MangledName.startswith("_Z11dot_acc_sat"));
+    IsFirstSigned = (IsDot) ? (MangledName[MangledName.size() - 3] == 'i')
+                            : (MangledName[MangledName.size() - 4] == 'i');
+    IsSecondSigned = (IsDot) ? (MangledName[MangledName.size() - 2] == 'i')
+                             : (MangledName[MangledName.size() - 3] == 'i');
   }
   AttributeList Attrs = CI->getCalledFunction()->getAttributes();
   mutateCallInstSPIRV(
@@ -1427,7 +1403,7 @@ void OCLToSPIRVBase::visitCallDot(CallInst *CI, StringRef MangledName,
           std::swap(Args[0], Args[1]);
         }
         Op OC;
-        if (!IsAccSat) {
+        if (IsDot) {
           OC = (IsFirstSigned != IsSecondSigned
                     ? OpSUDot
                     : ((IsFirstSigned) ? OpSDot : OpUDot));
@@ -1436,38 +1412,11 @@ void OCLToSPIRVBase::visitCallDot(CallInst *CI, StringRef MangledName,
                     ? OpSUDotAccSat
                     : ((IsFirstSigned) ? OpSDotAccSat : OpUDotAccSat));
         }
-        if (IsPacked) {
-          // As per SPIRV specification the dot OpCodes
-          // which use scalar integers to represent
-          // packed vectors need additional argument
-          // specified - the Packed Vector Format
-          Args.push_back(
-              getInt32(M, PackedVectorFormatPackedVectorFormat4x8BitKHR));
-        }
         return getSPIRVFuncName(OC);
       },
       &Attrs);
 }
 
-void OCLToSPIRVBase::visitCallClockRead(CallInst *CI, StringRef MangledName,
-                                        StringRef DemangledName) {
-  // The builtin returns i64 or <2 x i32>, but both variants are mapped to the
-  // same instruction; hence include the return type.
-  const std::string OpName = getSPIRVFuncName(OpReadClockKHR, CI->getType());
-
-  // Scope is part of the OpenCL builtin name.
-  const Scope ScopeArg = StringSwitch<Scope>(DemangledName)
-                             .EndsWith("device", ScopeDevice)
-                             .EndsWith("work_group", ScopeWorkgroup)
-                             .EndsWith("sub_group", ScopeSubgroup)
-                             .Default(ScopeMax);
-
-  mutateCallInstSPIRV(M, CI, [=](CallInst *, std::vector<Value *> &Args) {
-    Args.push_back(getInt32(M, ScopeArg));
-    return OpName;
-  });
-}
-
 void OCLToSPIRVBase::visitCallScalToVec(CallInst *CI, StringRef MangledName,
                                         StringRef DemangledName) {
   // Check if all arguments have the same type - it's simple case.
@@ -1921,37 +1870,6 @@ void OCLToSPIRVBase::visitSubgroupAVCBuiltinCallWithSampler(
       &Attrs);
 }
 
-void OCLToSPIRVBase::visitCallSplitBarrierINTEL(CallInst *CI,
-                                                StringRef DemangledName) {
-  auto Lit = getBarrierLiterals(CI);
-  AttributeList Attrs = CI->getCalledFunction()->getAttributes();
-  Op OpCode =
-      StringSwitch<Op>(DemangledName)
-          .Case("intel_work_group_barrier_arrive", OpControlBarrierArriveINTEL)
-          .Case("intel_work_group_barrier_wait", OpControlBarrierWaitINTEL)
-          .Default(OpNop);
-
-  mutateCallInstSPIRV(
-      M, CI,
-      [=](CallInst *, std::vector<Value *> &Args) {
-        Args.resize(3);
-        // Execution scope
-        Args[0] = addInt32(map<Scope>(std::get<2>(Lit)));
-        // Memory scope
-        Args[1] = addInt32(map<Scope>(std::get<1>(Lit)));
-        // Memory semantics
-        // OpControlBarrierArriveINTEL -> Release,
-        // OpControlBarrierWaitINTEL -> Acquire
-        unsigned MemFenceFlag = std::get<0>(Lit);
-        OCLMemOrderKind MemOrder = OpCode == OpControlBarrierArriveINTEL
-                                       ? OCLMO_release
-                                       : OCLMO_acquire;
-        Args[2] = addInt32(mapOCLMemSemanticToSPIRV(MemFenceFlag, MemOrder));
-        return getSPIRVFuncName(OpCode);
-      },
-      &Attrs);
-}
-
 void OCLToSPIRVBase::visitCallLdexp(CallInst *CI, StringRef MangledName,
                                     StringRef DemangledName) {
   auto Args = getArguments(CI);
