@@ -215,10 +215,6 @@ public:
   void visitCallDot(CallInst *CI, StringRef MangledName,
                     StringRef DemangledName);
 
-  /// Transform clock_read_* calls to OpReadClockKHR instructions.
-  void visitCallClockRead(CallInst *CI, StringRef MangledName,
-                          StringRef DemangledName);
-
   /// Fixes for built-in functions with vector+scalar arguments that are
   /// translated to the SPIR-V instructions where all arguments must have the
   /// same type.
@@ -251,9 +247,6 @@ public:
   void visitSubgroupAVCBuiltinCallWithSampler(CallInst *CI,
                                               StringRef DemangledName);
 
-  /// For cl_intel_split_work_group_barrier built-ins:
-  void visitCallSplitBarrierINTEL(CallInst *CI, StringRef DemangledName);
-
   void visitCallLdexp(CallInst *CI, StringRef MangledName,
                       StringRef DemangledName);
 
