@@ -432,9 +432,6 @@ template <> void SPIRVMap<std::string, Op, SPIRVInstruction>::init() {
   _SPIRV_OP(bitfield_extract_signed, BitFieldSExtract)
   _SPIRV_OP(bitfield_extract_unsigned, BitFieldUExtract)
   _SPIRV_OP(bit_reverse, BitReverse)
-  // cl_khr_split_work_group_barrier
-  _SPIRV_OP(intel_work_group_barrier_arrive, ControlBarrierArriveINTEL)
-  _SPIRV_OP(intel_work_group_barrier_wait, ControlBarrierWaitINTEL)
 #undef _SPIRV_OP
 }
 
@@ -646,9 +643,6 @@ template <> void LLVMSPIRVAtomicRmwOpCodeMap::init() {
   add(llvm::AtomicRMWInst::Min, OpAtomicSMin);
   add(llvm::AtomicRMWInst::UMax, OpAtomicUMax);
   add(llvm::AtomicRMWInst::UMin, OpAtomicUMin);
-  add(llvm::AtomicRMWInst::FAdd, OpAtomicFAddEXT);
-  add(llvm::AtomicRMWInst::FMin, OpAtomicFMinEXT);
-  add(llvm::AtomicRMWInst::FMax, OpAtomicFMaxEXT);
 }
 
 } // namespace SPIRV
@@ -1044,9 +1038,7 @@ public:
     } else if (NameRef.contains("barrier")) {
       addUnsignedArg(0);
       if (NameRef.equals("work_group_barrier") ||
-          NameRef.equals("sub_group_barrier") ||
-          NameRef.equals("intel_work_group_barrier_arrive") ||
-          NameRef.equals("intel_work_group_barrier_wait"))
+          NameRef.equals("sub_group_barrier"))
         setEnumArg(1, SPIR::PRIMITIVE_MEMORY_SCOPE);
     } else if (NameRef.startswith("atomic_work_item_fence")) {
       addUnsignedArg(0);
@@ -1490,8 +1482,8 @@ std::string getIntelSubgroupBlockDataPostfix(unsigned ElementBitSize,
     OSS << VectorNumElements;
     break;
   case 16:
-    assert((ElementBitSize == 8 || ElementBitSize == 16) &&
-           "16 elements vector allowed only for char and short builtins");
+    assert(ElementBitSize == 8 &&
+           "16 elements vector allowed only for char builtins");
     OSS << VectorNumElements;
     break;
   default:
