@@ -94,19 +94,11 @@ enum OCLScopeKind {
 // To avoid any inconsistence here, constants are explicitly initialized with
 // the corresponding constants from 'std::memory_order' enum.
 enum OCLMemOrderKind {
-#if __cplusplus >= 202002L
-  OCLMO_relaxed = static_cast<int>(std::memory_order::relaxed),
-  OCLMO_acquire = static_cast<int>(std::memory_order::acquire),
-  OCLMO_release = static_cast<int>(std::memory_order::release),
-  OCLMO_acq_rel = static_cast<int>(std::memory_order::acq_rel),
-  OCLMO_seq_cst = static_cast<int>(std::memory_order::seq_cst)
-#else
   OCLMO_relaxed = std::memory_order::memory_order_relaxed,
   OCLMO_acquire = std::memory_order::memory_order_acquire,
   OCLMO_release = std::memory_order::memory_order_release,
   OCLMO_acq_rel = std::memory_order::memory_order_acq_rel,
   OCLMO_seq_cst = std::memory_order::memory_order_seq_cst
-#endif
 };
 
 enum IntelFPGAMemoryAccessesVal {
@@ -239,12 +231,9 @@ const static char AtomicInit[] = "atomic_init";
 const static char AtomicWorkItemFence[] = "atomic_work_item_fence";
 const static char Barrier[] = "barrier";
 const static char Clamp[] = "clamp";
-const static char ClockReadPrefix[] = "clock_read_";
 const static char ConvertPrefix[] = "convert_";
 const static char Dot[] = "dot";
 const static char DotAccSat[] = "dot_acc_sat";
-const static char Dot4x8PackedPrefix[] = "dot_4x8packed_";
-const static char DotAccSat4x8PackedPrefix[] = "dot_acc_sat_4x8packed_";
 const static char EnqueueKernel[] = "enqueue_kernel";
 const static char FixedSqrtINTEL[] = "intel_arbitrary_fixed_sqrt";
 const static char FixedRecipINTEL[] = "intel_arbitrary_fixed_recip";
@@ -316,7 +305,6 @@ const static char SubgroupBlockWriteINTELPrefix[] =
     "intel_sub_group_block_write";
 const static char SubgroupImageMediaBlockINTELPrefix[] =
     "intel_sub_group_media_block";
-const static char SplitBarrierINTELPrefix[] = "intel_work_group_barrier_";
 const static char LDEXP[] = "ldexp";
 #define _SPIRV_OP(x)                                                           \
   const static char ConvertBFloat16##x##AsUShort##x[] =                        \
@@ -456,12 +444,11 @@ void decodeMDNode(MDNode *N, unsigned &X, unsigned &Y, unsigned &Z);
 template <typename T> std::string getFullPath(const T *Scope) {
   if (!Scope)
     return std::string();
-  StringRef Filename = Scope->getFilename();
-  auto Style = sys::path::Style::native;
-  if (sys::path::is_absolute(Filename, Style))
-    return Filename.str();
+  std::string Filename = Scope->getFilename().str();
+  if (sys::path::is_absolute(Filename))
+    return Filename;
   SmallString<16> DirName = Scope->getDirectory();
-  sys::path::append(DirName, Style, Filename.str());
+  sys::path::append(DirName, sys::path::Style::posix, Filename);
   return DirName.str().str();
 }
 
