@@ -59,7 +59,6 @@ using namespace llvm;
 
 namespace llvm {
 class IntrinsicInst;
-class IRBuilderBase;
 }
 
 namespace SPIRV {
@@ -193,7 +192,6 @@ enum SPIRAddressSpace {
   SPIRAS_GlobalHost,
   SPIRAS_Input,
   SPIRAS_Output,
-  SPIRAS_CodeSectionINTEL,
   SPIRAS_Count,
 };
 
@@ -204,8 +202,6 @@ template <> inline void SPIRVMap<SPIRAddressSpace, std::string>::init() {
   add(SPIRAS_Local, "Local");
   add(SPIRAS_Generic, "Generic");
   add(SPIRAS_Input, "Input");
-  add(SPIRAS_CodeSectionINTEL, "CodeSectionINTEL");
-
   add(SPIRAS_GlobalDevice, "GlobalDevice");
   add(SPIRAS_GlobalHost, "GlobalHost");
 }
@@ -222,7 +218,6 @@ inline void SPIRVMap<SPIRAddressSpace, SPIRVStorageClassKind>::init() {
   add(SPIRAS_Input, StorageClassInput);
   add(SPIRAS_GlobalDevice, StorageClassDeviceOnlyINTEL);
   add(SPIRAS_GlobalHost, StorageClassHostOnlyINTEL);
-  add(SPIRAS_CodeSectionINTEL, StorageClassCodeSectionINTEL);
 }
 typedef SPIRVMap<SPIRAddressSpace, SPIRVStorageClassKind> SPIRSPIRVAddrSpaceMap;
 
@@ -245,7 +240,6 @@ inline void SPIRVMap<Attribute::AttrKind, SPIRVFuncParamAttrKind>::init() {
   add(Attribute::NoAlias, FunctionParameterAttributeNoAlias);
   add(Attribute::NoCapture, FunctionParameterAttributeNoCapture);
   add(Attribute::ReadOnly, FunctionParameterAttributeNoWrite);
-  add(Attribute::ReadNone, FunctionParameterAttributeNoReadWrite);
 }
 typedef SPIRVMap<Attribute::AttrKind, SPIRVFuncParamAttrKind>
     SPIRSPIRVFuncParamAttrMap;
@@ -257,7 +251,7 @@ SPIRVMap<Attribute::AttrKind, SPIRVFunctionControlMaskKind>::init() {
   add(Attribute::ReadOnly, FunctionControlConstMask);
   add(Attribute::AlwaysInline, FunctionControlInlineMask);
   add(Attribute::NoInline, FunctionControlDontInlineMask);
-  add(Attribute::OptimizeNone, FunctionControlOptNoneEXTMask);
+  add(Attribute::OptimizeNone, internal::FunctionControlOptNoneINTELMask);
 }
 typedef SPIRVMap<Attribute::AttrKind, SPIRVFunctionControlMaskKind>
     SPIRSPIRVFuncCtlMaskMap;
@@ -317,8 +311,6 @@ const static char Float[] = "float";
 const static char Half[] = "half";
 const static char Int[] = "int";
 const static char UInt[] = "uint";
-const static char Long[] = "long";
-const static char ULong[] = "ulong";
 const static char Void[] = "void";
 } // namespace kSPIRVImageSampledTypeName
 
@@ -340,7 +332,6 @@ const static char PipeStorage[] = "PipeStorage";
 const static char ConstantPipeStorage[] = "ConstantPipeStorage";
 const static char VmeImageINTEL[] = "VmeImageINTEL";
 const static char JointMatrixINTEL[] = "JointMatrixINTEL";
-const static char CooperativeMatrixKHR[] = "CooperativeMatrixKHR";
 } // namespace kSPIRVTypeName
 
 namespace kSPR2TypeName {
@@ -390,11 +381,6 @@ const static char TranslateSPIRVMemOrder[] = "__translate_spirv_memory_order";
 const static char TranslateSPIRVMemScope[] = "__translate_spirv_memory_scope";
 const static char TranslateSPIRVMemFence[] = "__translate_spirv_memory_fence";
 const static char EntrypointPrefix[] = "__spirv_entry_";
-const static char ConvertHandleToImageINTEL[] = "ConvertHandleToImageINTEL";
-const static char ConvertHandleToSamplerINTEL[] = "ConvertHandleToSamplerINTEL";
-const static char ConvertHandleToSampledImageINTEL[] =
-    "ConvertHandleToSampledImageINTEL";
-const static char InternalBuiltinPrefix[] = "__builtin_spirv_";
 } // namespace kSPIRVName
 
 namespace kSPIRVPostfix {
@@ -586,10 +572,6 @@ std::string mapLLVMTypeToOCLType(const Type *Ty, bool Signed,
                                  Type *PointerElementType = nullptr);
 SPIRVDecorate *mapPostfixToDecorate(StringRef Postfix, SPIRVEntry *Target);
 
-/// Return vector V extended with poison elements to match the number of
-/// components of NewType.
-Value *extendVector(Value *V, FixedVectorType *NewType, IRBuilderBase &Builder);
-
 /// Add decorations to a SPIR-V entry.
 /// \param Decs Each string is a postfix without _ at the beginning.
 SPIRVValue *addDecorations(SPIRVValue *Target,
@@ -695,7 +677,7 @@ Op getSPIRVFuncOC(StringRef Name, SmallVectorImpl<std::string> *Dec = nullptr);
 bool getSPIRVBuiltin(const std::string &Name, spv::BuiltIn &Builtin);
 
 /// \param Name LLVM function name
-/// \param DemangledName demangled name of the OpenCL built-in function
+/// \param DemangledName demanged name of the OpenCL built-in function
 /// \returns true if Name is the name of the OpenCL built-in function,
 /// false for other functions
 bool oclIsBuiltin(StringRef Name, StringRef &DemangledName, bool IsCpp = false);
@@ -772,9 +754,6 @@ CallInst *addCallInst(Module *M, StringRef FuncName, Type *RetTy,
                       StringRef InstName = SPIR_TEMP_NAME_PREFIX_CALL,
                       bool TakeFuncName = true);
 
-/// Check if an LLVM type is spirv.CooperativeMatrixKHR.
-bool isLLVMCooperativeMatrixType(llvm::Type *Ty);
-
 /// Add a call instruction for SPIR-V builtin function.
 CallInst *addCallInstSPIRV(Module *M, StringRef FuncName, Type *RetTy,
                            ArrayRef<Value *> Args, AttributeList *Attrs,
@@ -945,9 +924,6 @@ std::string getImageBaseTypeName(StringRef Name);
 /// Map OpenCL opaque type name to SPIR-V type name.
 std::string mapOCLTypeNameToSPIRV(StringRef Name, StringRef Acc = "");
 
-/// Return the index of image operands given an image op.
-size_t getImageOperandsIndex(Op OpCode);
-
 /// Check if access qualifier is encoded in the type name.
 bool hasAccessQualifiedName(StringRef TyName);
 
@@ -1021,12 +997,10 @@ std::string getSPIRVFriendlyIRFunctionName(OCLExtOpKind ExtOpId,
 /// \param OC opcode of corresponding built-in instruction. Used to gather info
 /// for unsigned/constant arguments.
 /// \param Types of arguments of SPIR-V built-in function
-/// \param Ops Operands of SPIRVInstruction
 /// \return IA64 mangled name.
 std::string getSPIRVFriendlyIRFunctionName(const std::string &UniqName,
                                            spv::Op OC, ArrayRef<Type *> ArgTys,
-                                           ArrayRef<PointerIndirectPair> PETs,
-                                           ArrayRef<SPIRVValue *> Ops);
+                                           ArrayRef<PointerIndirectPair> PETs);
 
 /// Cast a function to a void(void) funtion pointer.
 Constant *castToVoidFuncPtr(Function *F);
@@ -1060,7 +1034,6 @@ template <> inline void SPIRVMap<std::string, Op, SPIRVOpaqueType>::init() {
   _SPIRV_OP(AvcImeDualReferenceStreaminINTEL)
   _SPIRV_OP(AvcRefResultINTEL)
   _SPIRV_OP(AvcSicResultINTEL)
-  _SPIRV_OP(CooperativeMatrixKHR)
 #undef _SPIRV_OP
 }
 
@@ -1082,7 +1055,7 @@ std::string decodeSPIRVTypeName(StringRef Name,
                                 SmallVectorImpl<std::string> &Strs);
 
 // Copy attributes from function to call site.
-CallInst *setAttrByCalledFunc(CallInst *Call);
+void setAttrByCalledFunc(CallInst *Call);
 bool isSPIRVBuiltinVariable(GlobalVariable *GV, SPIRVBuiltinVariableKind *Kind);
 // Transform builtin variable from GlobalVariable to builtin call.
 // e.g.
@@ -1093,13 +1066,6 @@ bool lowerBuiltinVariableToCall(GlobalVariable *GV,
 // Transform all builtin variables into calls
 bool lowerBuiltinVariablesToCalls(Module *M);
 
-// Transform all builtin calls into variables
-bool lowerBuiltinCallsToVariables(Module *M);
-
-//  Transform all builtins into variables or calls
-//  depending on user specification
-bool lowerBuiltins(SPIRVModule *BM, Module *M);
-
 /// \brief Post-process OpenCL or SPIRV builtin function returning struct type.
 ///
 /// Some builtin functions are translated to SPIR-V instructions with
@@ -1119,176 +1085,6 @@ bool postProcessBuiltinsWithArrayArguments(Module *M, bool IsCpp = false);
 
 template <typename T>
 MetadataAsValue *map2MDString(LLVMContext &C, SPIRVValue *V);
-
-/// Returns the smallest integral power of two no smaller than Value if Value is
-/// nonzero.  Returns 1 otherwise.
-///
-/// Ex. bitCeil(5) == 8.
-///
-/// The return value is undefined if the input is larger than the largest power
-/// of two representable in SPIRVWord.
-[[nodiscard]] SPIRVWord bitCeil(SPIRVWord Value);
-
-/// \param MangledName LLVM function name.
-/// \param DemangledName demangled name of the input function if it is the
-/// translator's internal built-in function.
-/// \returns true if MangledName is the name of the translator's internal
-/// built-in function, false for other functions.
-/// Used for 'mini'-floats conversion functions
-bool isInternalSPIRVBuiltin(StringRef MangledName, std::string &DemangledName);
-
-// Wrapper around SPIR-V 1.6.4 FP Encoding to be used in the conversion
-// descriptor
-enum FPEncodingWrap {
-  Integer = FPEncoding::FPEncodingMax - 1,
-  IEEE754 = FPEncoding::FPEncodingMax,
-  BF16 = FPEncoding::FPEncodingBFloat16KHR,
-  E4M3 = FPEncoding::FPEncodingFloat8E4M3EXT,
-  E5M2 = FPEncoding::FPEncodingFloat8E5M2EXT,
-  E2M1 = internal::FPEncodingFloat4E2M1INTEL,
-};
-
-// Structure describing non-trivial conversions (FP8 and int4)
-struct FPConversionDesc {
-public:
-  FPEncodingWrap SrcEncoding;
-  FPEncodingWrap DstEncoding;
-  SPIRVWord ConvOpCode;
-
-  // To use as a key in std::map
-  bool operator==(const FPConversionDesc &Other) const {
-    return SrcEncoding == Other.SrcEncoding &&
-           DstEncoding == Other.DstEncoding && ConvOpCode == Other.ConvOpCode;
-  }
-
-  bool operator<(const FPConversionDesc &Other) const {
-    if (ConvOpCode != Other.ConvOpCode)
-      return ConvOpCode < Other.ConvOpCode;
-    if (SrcEncoding != Other.SrcEncoding)
-      return SrcEncoding < Other.SrcEncoding;
-    return DstEncoding < Other.DstEncoding;
-  }
-};
-
-// Maps internal builtin name to conversion descriptor
-typedef SPIRVMap<llvm::StringRef, FPConversionDesc> FPConvertToEncodingMap;
-
-// clang-format off
-template <> inline void FPConvertToEncodingMap::init() {
-  // 4-bit conversions
-  add("ConvertE2M1ToE4M3INTEL",
-      {FPEncodingWrap::E2M1,      FPEncodingWrap::E4M3,         OpFConvert});
-  add("ConvertE2M1ToE5M2INTEL",
-      {FPEncodingWrap::E2M1,      FPEncodingWrap::E5M2,         OpFConvert});
-  add("ConvertE2M1ToFP16INTEL",
-      {FPEncodingWrap::E2M1,      FPEncodingWrap::IEEE754,      OpFConvert});
-  add("ConvertE2M1ToBF16INTEL",
-      {FPEncodingWrap::E2M1,      FPEncodingWrap::BF16,         OpFConvert});
-
-  add("ConvertInt4ToE4M3INTEL",
-      {FPEncodingWrap::Integer,      FPEncodingWrap::E4M3,      OpConvertSToF});
-  add("ConvertInt4ToE5M2INTEL",
-      {FPEncodingWrap::Integer,      FPEncodingWrap::E5M2,      OpConvertSToF});
-  add("ConvertInt4ToFP16INTEL",
-      {FPEncodingWrap::Integer,      FPEncodingWrap::IEEE754,   OpConvertSToF});
-  add("ConvertInt4ToBF16INTEL",
-      {FPEncodingWrap::Integer,      FPEncodingWrap::BF16,      OpConvertSToF});
-  add("ConvertInt4ToInt8INTEL",
-      {FPEncodingWrap::Integer,      FPEncodingWrap::Integer,   OpSConvert});
-
-  add("ConvertFP16ToE2M1INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E2M1,      OpFConvert});
-  add("ConvertBF16ToE2M1INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E2M1,      OpFConvert});
-  add("ConvertFP16ToInt4INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::Integer,   OpConvertFToS});
-  add("ConvertBF16ToInt4INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::Integer,   OpConvertFToS});
-
-  // 8-bit conversions
-  add("ConvertE4M3ToFP16EXT",
-      {FPEncodingWrap::E4M3,         FPEncodingWrap::IEEE754,      OpFConvert});
-  add("ConvertE5M2ToFP16EXT",
-      {FPEncodingWrap::E5M2,         FPEncodingWrap::IEEE754,      OpFConvert});
-  add("ConvertE4M3ToBF16EXT",
-      {FPEncodingWrap::E4M3,         FPEncodingWrap::BF16,         OpFConvert});
-  add("ConvertE5M2ToBF16EXT",
-      {FPEncodingWrap::E5M2,         FPEncodingWrap::BF16,         OpFConvert});
-  add("ConvertFP16ToE4M3EXT",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E4M3,         OpFConvert});
-  add("ConvertFP16ToE5M2EXT",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E5M2,         OpFConvert});
-  add("ConvertBF16ToE4M3EXT",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E4M3,         OpFConvert});
-  add("ConvertBF16ToE5M2EXT",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E5M2,         OpFConvert});
-
-  // SPV_INTEL_fp_conversions
-  add("ClampConvertFP16ToE2M1INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E2M1,
-       internal::OpClampConvertFToFINTEL});
-  add("ClampConvertBF16ToE2M1INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E2M1,
-       internal::OpClampConvertFToFINTEL});
-  add("ClampConvertFP16ToE4M3INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E4M3,
-       internal::OpClampConvertFToFINTEL});
-  add("ClampConvertBF16ToE4M3INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E4M3,
-       internal::OpClampConvertFToFINTEL});
-  add("ClampConvertFP16ToE5M2INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E5M2,
-       internal::OpClampConvertFToFINTEL});
-  add("ClampConvertBF16ToE5M2INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E5M2,
-       internal::OpClampConvertFToFINTEL});
-  add("ClampConvertFP16ToInt4INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::Integer,
-       internal::OpClampConvertFToSINTEL});
-  add("ClampConvertBF16ToInt4INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::Integer,
-       internal::OpClampConvertFToSINTEL});
-
-  add("StochasticRoundFP16ToE5M2INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E5M2,
-       internal::OpStochasticRoundFToFINTEL});
-  add("StochasticRoundFP16ToE4M3INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E4M3,
-       internal::OpStochasticRoundFToFINTEL});
-  add("StochasticRoundBF16ToE5M2INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E5M2,
-       internal::OpStochasticRoundFToFINTEL});
-  add("StochasticRoundBF16ToE4M3INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E4M3,
-       internal::OpStochasticRoundFToFINTEL});
-  add("StochasticRoundFP16ToE2M1INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E2M1,
-       internal::OpStochasticRoundFToFINTEL});
-  add("StochasticRoundBF16ToE2M1INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E2M1,
-       internal::OpStochasticRoundFToFINTEL});
-  add("ClampStochasticRoundFP16ToInt4INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::Integer,
-       internal::OpClampStochasticRoundFToSINTEL});
-  add("ClampStochasticRoundBF16ToInt4INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::Integer,
-       internal::OpClampStochasticRoundFToSINTEL});
-
-  add("ClampStochasticRoundFP16ToE5M2INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E5M2,
-       internal::OpClampStochasticRoundFToFINTEL});
-  add("ClampStochasticRoundFP16ToE4M3INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E4M3,
-       internal::OpClampStochasticRoundFToFINTEL});
-  add("ClampStochasticRoundBF16ToE5M2INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E5M2,
-       internal::OpClampStochasticRoundFToFINTEL});
-  add("ClampStochasticRoundBF16ToE4M3INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E4M3,
-       internal::OpClampStochasticRoundFToFINTEL});
-}
-
-// clang-format on
 } // namespace SPIRV
 
 #endif // SPIRV_SPIRVINTERNAL_H
