@@ -118,10 +118,6 @@ void SPIRVToOCLBase::visitCallInst(CallInst &CI) {
   if (OC == OpControlBarrier) {
     visitCallSPIRVControlBarrier(&CI);
   }
-  if (isSplitBarrierINTELOpCode(OC)) {
-    visitCallSPIRVSplitBarrierINTEL(&CI, OC);
-    return;
-  }
   if (isAtomicOpCode(OC)) {
     visitCallSPIRVAtomicBuiltin(&CI, OC);
     return;
@@ -209,10 +205,6 @@ void SPIRVToOCLBase::visitCallInst(CallInst &CI) {
       visitCallSPIRVRelational(&CI, OC);
     return;
   }
-  if (OC == OpReadClockKHR) {
-    visitCallSPIRVReadClockKHR(&CI);
-    return;
-  }
   if (OC == internal::OpConvertFToBF16INTEL ||
       OC == internal::OpConvertBF16ToFINTEL) {
     visitCallSPIRVBFloat16Conversions(&CI, OC);
@@ -237,10 +229,6 @@ void SPIRVToOCLBase::visitCastInst(CastInst &Cast) {
       DstVecTy->getScalarSizeInBits() == 1)
     return;
 
-  // We don't have OpenCL builtins for 4-bit conversions.
-  if (DstVecTy->getScalarSizeInBits() == 4 || SrcTy->getScalarSizeInBits() == 4)
-    return;
-
   // Assemble built-in name -> convert_gentypeN
   std::string CastBuiltInName(kOCLBuiltinName::ConvertPrefix);
   // Check if this is 'floating point -> unsigned integer' cast
@@ -1247,34 +1235,6 @@ void SPIRVToOCLBase::visitCallSPIRVRelational(CallInst *CI, Op OC) {
       &Attrs);
 }
 
-void SPIRVToOCLBase::visitCallSPIRVReadClockKHR(CallInst *CI) {
-  std::string Name("clock_read_");
-
-  if (CI->getType()->isVectorTy())
-    Name += "hilo_";
-
-  // Encode the scope (taken from the argument) in the function name.
-  ConstantInt *ScopeOp = cast<ConstantInt>(CI->getArgOperand(0));
-  switch (static_cast<Scope>(ScopeOp->getZExtValue())) {
-  case ScopeDevice:
-    Name += "device";
-    break;
-  case ScopeWorkgroup:
-    Name += "work_group";
-    break;
-  case ScopeSubgroup:
-    Name += "sub_group";
-    break;
-  default:
-    break;
-  }
-
-  mutateCallInstOCL(M, CI, [=](CallInst *Call, std::vector<Value *> &Args) {
-    Args.pop_back();
-    return Name;
-  });
-}
-
 std::string SPIRVToOCLBase::getGroupBuiltinPrefix(CallInst *CI) {
   std::string Prefix;
   auto ES = getArgAsScope(CI, 0);
