@@ -222,12 +222,6 @@ public:
   /// - OCL1.2: barrier
   virtual void visitCallSPIRVControlBarrier(CallInst *CI) = 0;
 
-  /// Transform split __spirv_ControlBarrierArriveINTEL and
-  /// __spirv_ControlBarrierWaitINTEL barrier to:
-  /// - OCL2.0: overload with a memory_scope argument
-  /// - OCL1.2: overload with no memory_scope argument
-  virtual void visitCallSPIRVSplitBarrierINTEL(CallInst *CI, Op OC) = 0;
-
   /// Transform __spirv_EnqueueKernel to __enqueue_kernel
   virtual void visitCallSPIRVEnqueueKernel(CallInst *CI, Op OC) = 0;
 
@@ -237,9 +231,6 @@ public:
   /// Transform relational builtin, e.g. __spirv_IsNan, to OpenCL builtin.
   void visitCallSPIRVRelational(CallInst *CI, Op OC);
 
-  /// Transform __spirv_ReadClockKHR to OpenCL builtin.
-  void visitCallSPIRVReadClockKHR(CallInst *CI);
-
   /// Conduct generic mutations for all atomic builtins
   virtual CallInst *mutateCommonAtomicArguments(CallInst *CI, Op OC) = 0;
 
@@ -314,11 +305,6 @@ public:
   ///       barrier(flag(sema))
   void visitCallSPIRVControlBarrier(CallInst *CI) override;
 
-  /// Transform split __spirv_ControlBarrierArriveINTEL and
-  /// __spirv_ControlBarrierWaitINTEL barrier to overloads without a
-  /// memory_scope argument.
-  void visitCallSPIRVSplitBarrierINTEL(CallInst *CI, Op OC) override;
-
   /// Transform __spirv_OpAtomic functions. It firstly conduct generic
   /// mutations for all builtins and then mutate some of them seperately
   Instruction *visitCallSPIRVAtomicBuiltin(CallInst *CI, Op OC) override;
@@ -408,11 +394,6 @@ public:
   ///         sub_group_barrier(flag(sema), map(memScope))
   void visitCallSPIRVControlBarrier(CallInst *CI) override;
 
-  /// Transform split __spirv_ControlBarrierArriveINTEL and
-  /// __spirv_ControlBarrierWaitINTEL barrier to overloads with a
-  /// memory_scope argument.
-  void visitCallSPIRVSplitBarrierINTEL(CallInst *CI, Op OC) override;
-
   /// Transform __spirv_Atomic* to atomic_*.
   ///   __spirv_Atomic*(atomic_op, scope, sema, ops, ...) =>
   ///      atomic_*(generic atomic_op, ops, ..., order(sema), map(scope))
