@@ -86,9 +86,7 @@ public:
   SPIRVType *transPointerType(SPIRVType *PointeeTy, unsigned AddrSpace);
   SPIRVType *transSPIRVOpaqueType(StringRef STName, unsigned AddrSpace);
   SPIRVType *
-  transSPIRVJointOrCooperativeMatrixType(SmallVector<std::string, 8> Postfixes,
-                                         bool IsCooperative = false);
-  // SPIRVType* transSPIRVCooperativeMatrixKHRType();
+  transSPIRVJointMatrixINTELType(SmallVector<std::string, 8> Postfixes);
   /// Use the type scavenger to get the correct type for V. This is equivalent
   /// to transType(V->getType()) if V is not a pointer type; otherwise, it tries
   /// to pick an appropriate pointee type for V.
@@ -107,18 +105,9 @@ public:
   bool transSourceLanguage();
   bool transExtension();
   bool transBuiltinSet();
+  bool transWorkItemBuiltinCallsToVariables();
   bool isKnownIntrinsic(Intrinsic::ID Id);
   SPIRVValue *transIntrinsicInst(IntrinsicInst *Intrinsic, SPIRVBasicBlock *BB);
-  enum class FPBuiltinType {
-    REGULAR_MATH,
-    EXT_1OPS,
-    EXT_2OPS,
-    EXT_3OPS,
-    UNKNOWN
-  };
-  FPBuiltinType getFPBuiltinType(IntrinsicInst *II, StringRef &);
-  SPIRVValue *transFPBuiltinIntrinsicInst(IntrinsicInst *II,
-                                          SPIRVBasicBlock *BB);
   SPIRVValue *transFenceInst(FenceInst *FI, SPIRVBasicBlock *BB);
   SPIRVValue *transCallInst(CallInst *Call, SPIRVBasicBlock *BB);
   SPIRVValue *transDirectCallInst(CallInst *Call, SPIRVBasicBlock *BB);
@@ -132,8 +121,6 @@ public:
   SPIRVFunction *transFunctionDecl(Function *F);
   void transVectorComputeMetadata(Function *F);
   void transFPGAFunctionMetadata(SPIRVFunction *BF, Function *F);
-  void transAuxDataInst(SPIRVFunction *BF, Function *F);
-  void transFunctionMetadataAsExecutionMode(SPIRVFunction *BF, Function *F);
   bool transGlobalVariables();
 
   Op transBoolOpCode(SPIRVValue *Opn, Op OC);
