@@ -42,7 +42,6 @@
 #include "SPIRVBasicBlock.h"
 #include "SPIRVDebug.h"
 #include "SPIRVDecorate.h"
-#include "SPIRVFnVar.h"
 #include "SPIRVFunction.h"
 #include "SPIRVInstruction.h"
 #include "SPIRVMemAliasingINTEL.h"
@@ -176,7 +175,7 @@ void SPIRVEntry::encodeLine(spv_ostream &O) const {
   if (!Module)
     return;
   const std::shared_ptr<const SPIRVLine> &CurrLine = Module->getCurrentLine();
-  if (Line && (!CurrLine || *Line != *CurrLine)) {
+  if (Line && ((CurrLine && *Line != *CurrLine) || !CurrLine)) {
     O << *Line;
     Module->setCurrentLine(Line);
   }
@@ -184,43 +183,8 @@ void SPIRVEntry::encodeLine(spv_ostream &O) const {
     Module->setCurrentLine(nullptr);
 }
 
-namespace {
-bool isDebugLineEqual(const SPIRVExtInst &DL1, const SPIRVExtInst &DL2) {
-  std::vector<SPIRVWord> DL1Args = DL1.getArguments();
-  std::vector<SPIRVWord> DL2Args = DL2.getArguments();
-
-  using namespace SPIRVDebug::Operand::DebugLine;
-  assert(DL1Args.size() == OperandCount && DL2Args.size() == OperandCount &&
-         "Invalid number of operands");
-  return DL1Args[SourceIdx] == DL2Args[SourceIdx] &&
-         DL1Args[StartIdx] == DL2Args[StartIdx] &&
-         DL1Args[EndIdx] == DL2Args[EndIdx] &&
-         DL1Args[ColumnStartIdx] == DL2Args[ColumnStartIdx] &&
-         DL1Args[ColumnEndIdx] == DL2Args[ColumnEndIdx];
-}
-} // namespace
-
-void SPIRVEntry::encodeDebugLine(spv_ostream &O) const {
-  if (!Module)
-    return;
-  const std::shared_ptr<const SPIRVExtInst> &CurrDebugLine =
-      Module->getCurrentDebugLine();
-  if (DebugLine &&
-      (!CurrDebugLine || !isDebugLineEqual(*DebugLine, *CurrDebugLine))) {
-    O << *DebugLine;
-    Module->setCurrentDebugLine(DebugLine);
-  }
-  if (isEndOfBlock() ||
-      isExtInst(SPIRVEIS_NonSemantic_Shader_DebugInfo_100,
-                SPIRVDebug::DebugNoLine) ||
-      isExtInst(SPIRVEIS_NonSemantic_Shader_DebugInfo_200,
-                SPIRVDebug::DebugNoLine))
-    Module->setCurrentDebugLine(nullptr);
-}
-
 void SPIRVEntry::encodeAll(spv_ostream &O) const {
   encodeLine(O);
-  encodeDebugLine(O);
   encodeWordCountOpCode(O);
   encode(O);
   encodeChildren(O);
@@ -337,11 +301,6 @@ void SPIRVEntry::setLine(const std::shared_ptr<const SPIRVLine> &L) {
   SPIRVDBG(if (L) spvdbgs() << "[setLine] " << *L << '\n';)
 }
 
-void SPIRVEntry::setDebugLine(const std::shared_ptr<const SPIRVExtInst> &DL) {
-  DebugLine = DL;
-  SPIRVDBG(if (DL) spvdbgs() << "[setDebugLine] " << *DL << '\n';)
-}
-
 void SPIRVEntry::addMemberDecorate(SPIRVMemberDecorate *Dec) {
   assert(canHaveMemberDecorates() &&
          MemberDecorates.find(Dec->getPair()) == MemberDecorates.end());
@@ -377,16 +336,6 @@ void SPIRVEntry::takeAnnotations(SPIRVForward *E) {
     static_cast<SPIRVFunction *>(this)->takeExecutionModes(E);
 }
 
-void SPIRVEntry::replaceTargetIdInDecorates(SPIRVId Id) {
-  for (auto It = Decorates.begin(), E = Decorates.end(); It != E; ++It)
-    const_cast<SPIRVDecorate *>(It->second)->setTargetId(Id);
-  for (auto It = DecorateIds.begin(), E = DecorateIds.end(); It != E; ++It)
-    const_cast<SPIRVDecorateId *>(It->second)->setTargetId(Id);
-  for (auto It = MemberDecorates.begin(), E = MemberDecorates.end(); It != E;
-       ++It)
-    const_cast<SPIRVMemberDecorate *>(It->second)->setTargetId(Id);
-}
-
 // Check if an entry has Kind of decoration and get the literal of the
 // first decoration of such kind at Index.
 bool SPIRVEntry::hasDecorate(Decoration Kind, size_t Index,
@@ -592,7 +541,7 @@ SPIRVEntryPoint::SPIRVEntryPoint(SPIRVModule *TheModule,
                                  SPIRVExecutionModelKind TheExecModel,
                                  SPIRVId TheId, const std::string &TheName,
                                  std::vector<SPIRVId> Variables)
-    : SPIRVAnnotation(OpEntryPoint, TheModule->get<SPIRVFunction>(TheId),
+    : SPIRVAnnotation(TheModule->get<SPIRVFunction>(TheId),
                       getSizeInWords(TheName) + Variables.size() + 3),
       ExecModel(TheExecModel), Name(TheName), Variables(Variables) {}
 
@@ -616,9 +565,7 @@ void SPIRVExecutionMode::decode(std::istream &I) {
   getDecoder(I) >> Target >> ExecMode;
   switch (static_cast<uint32_t>(ExecMode)) {
   case ExecutionModeLocalSize:
-  case ExecutionModeLocalSizeId:
   case ExecutionModeLocalSizeHint:
-  case ExecutionModeLocalSizeHintId:
   case ExecutionModeMaxWorkgroupSizeINTEL:
     WordLiterals.resize(3);
     break;
@@ -637,15 +584,10 @@ void SPIRVExecutionMode::decode(std::istream &I) {
   case ExecutionModeSharedLocalMemorySizeINTEL:
   case ExecutionModeNamedBarrierCountINTEL:
   case ExecutionModeSubgroupSize:
-  case ExecutionModeSubgroupsPerWorkgroup:
-  case ExecutionModeSubgroupsPerWorkgroupId:
   case ExecutionModeMaxWorkDimINTEL:
   case ExecutionModeNumSIMDWorkitemsINTEL:
   case ExecutionModeSchedulerTargetFmaxMhzINTEL:
-  case ExecutionModeStreamingInterfaceINTEL:
-  case ExecutionModeMaximumRegistersINTEL:
-  case ExecutionModeMaximumRegistersIdINTEL:
-  case ExecutionModeNamedMaximumRegistersINTEL:
+  case internal::ExecutionModeStreamingInterfaceINTEL:
     WordLiterals.resize(1);
     break;
   default:
@@ -667,8 +609,7 @@ SPIRVForward *SPIRVAnnotationGeneric::getOrCreateTarget() const {
 }
 
 SPIRVName::SPIRVName(const SPIRVEntry *TheTarget, const std::string &TheStr)
-    : SPIRVAnnotation(OpName, TheTarget, getSizeInWords(TheStr) + 2),
-      Str(TheStr) {}
+    : SPIRVAnnotation(TheTarget, getSizeInWords(TheStr) + 2), Str(TheStr) {}
 
 void SPIRVName::encode(spv_ostream &O) const { getEncoder(O) << Target << Str; }
 
@@ -690,6 +631,8 @@ void SPIRVLine::encode(spv_ostream &O) const {
 
 void SPIRVLine::decode(std::istream &I) {
   getDecoder(I) >> FileName >> Line >> Column;
+  std::shared_ptr<const SPIRVLine> L(this);
+  Module->setCurrentLine(L);
 }
 
 void SPIRVLine::validate() const {
