@@ -71,12 +71,7 @@ inline bool isAtomicOpCode(Op OpCode) {
 }
 inline bool isBinaryOpCode(Op OpCode) {
   return ((unsigned)OpCode >= OpIAdd && (unsigned)OpCode <= OpFMod) ||
-         OpCode == OpDot || OpCode == OpIAddCarry || OpCode == OpISubBorrow ||
-         OpCode == OpUMulExtended || OpCode == OpSMulExtended;
-}
-
-inline bool isBinaryPtrOpCode(Op OpCode) {
-  return (unsigned)OpCode >= OpPtrEqual && (unsigned)OpCode <= OpPtrDiff;
+         OpCode == OpDot;
 }
 
 inline bool isShiftOpCode(Op OpCode) {
@@ -115,14 +110,6 @@ inline bool isCvtOpCode(Op OpCode) {
          OpCode == OpCrossWorkgroupCastToPtrINTEL;
 }
 
-inline bool isIntelCvtOpCode(Op OpCode) {
-  return OpCode == internal::OpClampConvertFToFINTEL ||
-         OpCode == internal::OpClampConvertFToSINTEL ||
-         OpCode == internal::OpStochasticRoundFToFINTEL ||
-         OpCode == internal::OpClampStochasticRoundFToFINTEL ||
-         OpCode == internal::OpClampStochasticRoundFToSINTEL;
-}
-
 inline bool isCvtToUnsignedOpCode(Op OpCode) {
   return OpCode == OpConvertFToU || OpCode == OpUConvert ||
          OpCode == OpSatConvertSToU;
@@ -237,28 +224,18 @@ inline bool isTypeOpCode(Op OpCode) {
   return (OpTypeVoid <= OC && OC <= OpTypePipe) || OC == OpTypePipeStorage ||
          isSubgroupAvcINTELTypeOpCode(OpCode) || OC == OpTypeVmeImageINTEL ||
          isVCOpCode(OpCode) || OC == internal::OpTypeTokenINTEL ||
-         OC == internal::OpTypeJointMatrixINTEL ||
-         OC == OpTypeCooperativeMatrixKHR;
-}
-
-inline bool isFnVarSpecConstINTEL(Op OpCode) {
-  const unsigned OC = OpCode;
-  return OC == OpSpecConstantArchitectureINTEL ||
-         OC == OpSpecConstantTargetINTEL ||
-         OC == OpSpecConstantCapabilitiesINTEL;
+         OC == internal::OpTypeJointMatrixINTEL;
 }
 
 inline bool isSpecConstantOpCode(Op OpCode) {
   unsigned OC = OpCode;
-  return (OpSpecConstantTrue <= OC && OC <= OpSpecConstantOp) ||
-         isFnVarSpecConstINTEL(OpCode);
+  return OpSpecConstantTrue <= OC && OC <= OpSpecConstantOp;
 }
 
 inline bool isConstantOpCode(Op OpCode) {
   unsigned OC = OpCode;
   return (OpConstantTrue <= OC && OC <= OpSpecConstantOp) || OC == OpUndef ||
-         OC == OpConstantPipeStorage || OC == OpConstantFunctionPointerINTEL ||
-         isSpecConstantOpCode(OpCode);
+         OC == OpConstantPipeStorage || OC == OpConstantFunctionPointerINTEL;
 }
 
 inline bool isModuleScopeAllowedOpCode(Op OpCode) {
@@ -275,11 +252,6 @@ inline bool isEventOpCode(Op OpCode) {
   return OpRetainEvent <= OpCode && OpCode <= OpCaptureEventProfilingInfo;
 }
 
-inline bool isSplitBarrierINTELOpCode(Op OpCode) {
-  return OpCode == OpControlBarrierArriveINTEL ||
-         OpCode == OpControlBarrierWaitINTEL;
-}
-
 } // namespace SPIRV
 
 #endif // SPIRV_LIBSPIRV_SPIRVOPCODE_H
