@@ -115,9 +115,6 @@ SPIRVType *SPIRVType::getVectorComponentType() const {
     return static_cast<const SPIRVTypeVector *>(this)->getComponentType();
   if (OpCode == internal::OpTypeJointMatrixINTEL)
     return static_cast<const SPIRVTypeJointMatrixINTEL *>(this)->getCompType();
-  if (OpCode == OpTypeCooperativeMatrixKHR)
-    return static_cast<const SPIRVTypeCooperativeMatrixKHR *>(this)
-        ->getCompType();
   assert(0 && "getVectorComponentType(): Not a vector or joint matrix type");
   return nullptr;
 }
@@ -159,7 +156,7 @@ bool SPIRVType::isTypeBool() const { return OpCode == OpTypeBool; }
 
 bool SPIRVType::isTypeComposite() const {
   return isTypeVector() || isTypeArray() || isTypeStruct() ||
-         isTypeJointMatrixINTEL() || isTypeCooperativeMatrixKHR();
+         isTypeJointMatrixINTEL();
 }
 
 bool SPIRVType::isTypeFloat(unsigned Bits) const {
@@ -197,10 +194,6 @@ bool SPIRVType::isTypeSampler() const { return OpCode == OpTypeSampler; }
 
 bool SPIRVType::isTypeImage() const { return OpCode == OpTypeImage; }
 
-bool SPIRVType::isTypeSampledImage() const {
-  return OpCode == OpTypeSampledImage;
-}
-
 bool SPIRVType::isTypeStruct() const { return OpCode == OpTypeStruct; }
 
 bool SPIRVType::isTypeVector() const { return OpCode == OpTypeVector; }
@@ -209,10 +202,6 @@ bool SPIRVType::isTypeJointMatrixINTEL() const {
   return OpCode == internal::OpTypeJointMatrixINTEL;
 }
 
-bool SPIRVType::isTypeCooperativeMatrixKHR() const {
-  return OpCode == OpTypeCooperativeMatrixKHR;
-}
-
 bool SPIRVType::isTypeVectorBool() const {
   return isTypeVector() && getVectorComponentType()->isTypeBool();
 }
@@ -229,10 +218,6 @@ bool SPIRVType::isTypeVectorOrScalarBool() const {
   return isTypeBool() || isTypeVectorBool();
 }
 
-bool SPIRVType::isTypeVectorPointer() const {
-  return isTypeVector() && getVectorComponentType()->isTypePointer();
-}
-
 bool SPIRVType::isTypeSubgroupAvcINTEL() const {
   return isSubgroupAvcINTELTypeOpCode(OpCode);
 }
@@ -309,24 +294,4 @@ void SPIRVTypeJointMatrixINTEL::decode(std::istream &I) {
   Decoder >> Id >> CompType >> Args;
 }
 
-SPIRVTypeCooperativeMatrixKHR::SPIRVTypeCooperativeMatrixKHR(
-    SPIRVModule *M, SPIRVId TheId, SPIRVType *CompType,
-    std::vector<SPIRVValue *> Args)
-    : SPIRVType(M, FixedWC, OpTypeCooperativeMatrixKHR, TheId),
-      CompType(CompType), Args(std::move(Args)) {}
-
-SPIRVTypeCooperativeMatrixKHR::SPIRVTypeCooperativeMatrixKHR()
-    : SPIRVType(OpTypeCooperativeMatrixKHR), CompType(nullptr),
-      Args({nullptr, nullptr, nullptr, nullptr}) {}
-
-void SPIRVTypeCooperativeMatrixKHR::encode(spv_ostream &O) const {
-  auto Encoder = getEncoder(O);
-  Encoder << Id << CompType << Args;
-}
-
-void SPIRVTypeCooperativeMatrixKHR::decode(std::istream &I) {
-  auto Decoder = getDecoder(I);
-  Decoder >> Id >> CompType >> Args;
-}
-
 } // namespace SPIRV
