@@ -84,8 +84,7 @@ public:
   bool isTypeEvent() const;
   bool isTypeDeviceEvent() const;
   bool isTypeReserveId() const;
-  bool isTypeFloat(unsigned Bits = 0,
-                   unsigned FloatingPointEncoding = FPEncodingMax) const;
+  bool isTypeFloat(unsigned Bits = 0) const;
   bool isTypeImage() const;
   bool isTypeOCLImage() const;
   bool isTypePipe() const;
@@ -94,18 +93,15 @@ public:
   bool isTypeOpaque() const;
   bool isTypePointer() const;
   bool isTypeSampler() const;
-  bool isTypeSampledImage() const;
   bool isTypeStruct() const;
   bool isTypeVector() const;
   bool isTypeJointMatrixINTEL() const;
-  bool isTypeCooperativeMatrixKHR() const;
   bool isTypeVectorInt() const;
   bool isTypeVectorFloat() const;
   bool isTypeVectorBool() const;
   bool isTypeVectorOrScalarInt() const;
   bool isTypeVectorOrScalarFloat() const;
   bool isTypeVectorOrScalarBool() const;
-  bool isTypeVectorPointer() const;
   bool isTypeSubgroupAvcINTEL() const;
   bool isTypeSubgroupAvcMceINTEL() const;
 };
@@ -152,14 +148,6 @@ public:
   SPIRVCapVec getRequiredCapability() const override {
     SPIRVCapVec CV;
     switch (BitWidth) {
-    case 4: {
-      if (Module->isAllowedToUseExtension(ExtensionID::SPV_INTEL_int4)) {
-        CV.push_back(CapabilityInt4TypeINTEL);
-        return CV;
-      }
-      CV.push_back(CapabilityArbitraryPrecisionIntegersINTEL);
-      return CV;
-    }
     case 8:
       CV.push_back(CapabilityInt8);
       break;
@@ -180,11 +168,6 @@ public:
   }
   llvm::Optional<ExtensionID> getRequiredExtension() const override {
     switch (BitWidth) {
-    case 4: {
-      if (Module->isAllowedToUseExtension(ExtensionID::SPV_INTEL_int4))
-        return ExtensionID::SPV_INTEL_int4;
-      return ExtensionID::SPV_INTEL_arbitrary_precision_integers;
-    }
     case 8:
     case 16:
     case 32:
@@ -199,9 +182,7 @@ protected:
   _SPIRV_DEF_ENCDEC3(Id, BitWidth, IsSigned)
   void validate() const override {
     SPIRVEntry::validate();
-    assert(((BitWidth == 4 &&
-             Module->isAllowedToUseExtension(ExtensionID::SPV_INTEL_int4)) ||
-            BitWidth == 8 || BitWidth == 16 || BitWidth == 32 ||
+    assert((BitWidth == 8 || BitWidth == 16 || BitWidth == 32 ||
             BitWidth == 64 ||
             Module->isAllowedToUseExtension(
                 ExtensionID::SPV_INTEL_arbitrary_precision_integers)) &&
@@ -217,87 +198,35 @@ class SPIRVTypeFloat : public SPIRVType {
 public:
   static const Op OC = OpTypeFloat;
   // Complete constructor
-  SPIRVTypeFloat(SPIRVModule *M, SPIRVId TheId, unsigned TheBitWidth,
-                 unsigned TheFloatingPointEncoding)
-      : SPIRVType(M, 3 + (TheFloatingPointEncoding != FPEncodingMax), OC,
-                  TheId),
-        BitWidth(TheBitWidth), FloatingPointEncoding(TheFloatingPointEncoding) {
-  }
+  SPIRVTypeFloat(SPIRVModule *M, SPIRVId TheId, unsigned TheBitWidth)
+      : SPIRVType(M, 3, OC, TheId), BitWidth(TheBitWidth) {}
   // Incomplete constructor
-  SPIRVTypeFloat()
-      : SPIRVType(OC), BitWidth(0), FloatingPointEncoding(FPEncodingMax) {}
+  SPIRVTypeFloat() : SPIRVType(OC), BitWidth(0) {}
 
   unsigned getBitWidth() const { return BitWidth; }
 
-  unsigned getFloatingPointEncoding() const { return FloatingPointEncoding; }
-
-  llvm::Optional<ExtensionID> getRequiredExtension() const override {
-    if (isTypeFloat(16, FPEncodingBFloat16KHR))
-      return ExtensionID::SPV_KHR_bfloat16;
-    if (isTypeFloat(8, FPEncodingFloat8E4M3EXT) ||
-        isTypeFloat(8, FPEncodingFloat8E5M2EXT))
-      return ExtensionID::SPV_EXT_float8;
-    if (isTypeFloat(4, internal::FPEncodingFloat4E2M1INTEL))
-      return ExtensionID::SPV_INTEL_float4;
-    return {};
-  }
-
   SPIRVCapVec getRequiredCapability() const override {
     SPIRVCapVec CV;
-    if (isTypeFloat(16, FPEncodingBFloat16KHR)) {
-      CV.push_back(CapabilityBFloat16TypeKHR);
-    } else if (isTypeFloat(16)) {
+    if (isTypeFloat(16)) {
       CV.push_back(CapabilityFloat16Buffer);
       auto Extensions = getModule()->getSourceExtension();
       if (std::any_of(Extensions.begin(), Extensions.end(),
                       [](const std::string &I) { return I == "cl_khr_fp16"; }))
         CV.push_back(CapabilityFloat16);
-    } else if (isTypeFloat(64)) {
+    } else if (isTypeFloat(64))
       CV.push_back(CapabilityFloat64);
-    } else if (isTypeFloat(8, FPEncodingFloat8E4M3EXT) ||
-               isTypeFloat(8, FPEncodingFloat8E5M2EXT)) {
-      CV.push_back(CapabilityFloat8EXT);
-    } else if (isTypeFloat(4, internal::FPEncodingFloat4E2M1INTEL)) {
-      CV.push_back(internal::CapabilityFloat4E2M1INTEL);
-    }
     return CV;
   }
 
 protected:
-  void encode(spv_ostream &O) const override {
-    assert(WordCount == 3 || WordCount == 4);
-    auto Encoder = getEncoder(O);
-    Encoder << Id << BitWidth;
-    if (WordCount == 4)
-      Encoder << FloatingPointEncoding;
-  }
-
-  void decode(std::istream &I) override {
-    assert(WordCount == 3 || WordCount == 4);
-    auto Decoder = getDecoder(I);
-    Decoder >> Id >> BitWidth;
-    if (WordCount == 4)
-      Decoder >> FloatingPointEncoding;
-  }
-
+  _SPIRV_DEF_ENCDEC2(Id, BitWidth)
   void validate() const override {
     SPIRVEntry::validate();
-    assert((BitWidth == 4 || BitWidth == 8 || BitWidth == 16 ||
-            BitWidth == 32 || BitWidth == 64) &&
-           "Invalid bit width");
-    assert(
-        (FloatingPointEncoding == FPEncodingMax ||
-         (BitWidth == 16 && FloatingPointEncoding == FPEncodingBFloat16KHR) ||
-         (BitWidth == 8 && FloatingPointEncoding == FPEncodingFloat8E4M3EXT) ||
-         (BitWidth == 8 && FloatingPointEncoding == FPEncodingFloat8E5M2EXT) ||
-         (BitWidth == 4 &&
-          FloatingPointEncoding == internal::FPEncodingFloat4E2M1INTEL)) &&
-        "Invalid floating point encoding");
+    assert(BitWidth >= 16 && BitWidth <= 64 && "Invalid bit width");
   }
 
 private:
   unsigned BitWidth; // Bit width
-  unsigned FloatingPointEncoding;
 };
 
 class SPIRVTypePointer : public SPIRVType {
@@ -1160,48 +1089,5 @@ public:
   SPIRVValue *getUse() const { return Args.size() > 4 ? Args[4] : nullptr; }
 };
 
-class SPIRVTypeCooperativeMatrixKHR : public SPIRVType {
-  SPIRVType *CompType;
-  std::vector<SPIRVValue *> Args;
-
-public:
-  const static Op OC = OpTypeCooperativeMatrixKHR;
-  const static SPIRVWord FixedWC = 7;
-  // Incomplete constructor
-  SPIRVTypeCooperativeMatrixKHR(SPIRVModule *M, SPIRVId TheId,
-                                SPIRVType *CompType,
-                                std::vector<SPIRVValue *> Args);
-  // Incomplete constructor
-  SPIRVTypeCooperativeMatrixKHR();
-  _SPIRV_DCL_ENCDEC
-  llvm::Optional<ExtensionID> getRequiredExtension() const override {
-    SPIRVType *Ty = this->getCompType();
-    if (Ty->isTypeInt() && static_cast<SPIRVTypeInt *>(Ty)->getBitWidth() == 4)
-      this->getModule()->addExtension(ExtensionID::SPV_INTEL_int4);
-    return ExtensionID::SPV_KHR_cooperative_matrix;
-  }
-  SPIRVCapVec getRequiredCapability() const override {
-    auto CV = getVec(CapabilityCooperativeMatrixKHR);
-    if (CompType->isTypeFloat(16, FPEncodingBFloat16KHR))
-      CV.push_back(CapabilityBFloat16CooperativeMatrixKHR);
-    else if (CompType->isTypeInt() &&
-             static_cast<SPIRVTypeInt *>(CompType)->getBitWidth() == 4)
-      CV.push_back(CapabilityInt4CooperativeMatrixINTEL);
-    else if (CompType->isTypeFloat(8, FPEncodingFloat8E4M3EXT) ||
-             CompType->isTypeFloat(8, FPEncodingFloat8E5M2EXT))
-      CV.push_back(CapabilityFloat8CooperativeMatrixEXT);
-    else if (CompType->isTypeFloat(4, internal::FPEncodingFloat4E2M1INTEL))
-      CV.push_back(internal::CapabilityFloat4E2M1CooperativeMatrixINTEL);
-    return CV;
-  }
-
-  std::vector<SPIRVValue *> getArgs() const { return Args; }
-  SPIRVType *getCompType() const { return CompType; }
-  SPIRVValue *getScope() const { return Args[0]; }
-  SPIRVValue *getRows() const { return Args[1]; }
-  SPIRVValue *getColumns() const { return Args[2]; }
-  SPIRVValue *getUse() const { return Args[3]; }
-};
-
 } // namespace SPIRV
 #endif // SPIRV_LIBSPIRV_SPIRVTYPE_H
