@@ -269,8 +269,7 @@ public:
 protected:
   void validate() const override {
     SPIRVConstantEmpty::validate();
-    assert((Type->isTypeBool() || Type->isTypeInt() || Type->isTypeFloat() ||
-            Type->isTypeComposite() || Type->isTypeOpaque() ||
+    assert((Type->isTypeComposite() || Type->isTypeOpaque() ||
             Type->isTypeEvent() || Type->isTypePointer() ||
             Type->isTypeReserveId() || Type->isTypeDeviceEvent() ||
             (Type->isTypeSubgroupAvcINTEL() &&
