@@ -110,9 +110,7 @@ static cl::opt<VersionNumber> MaxSPIRVVersion(
                clEnumValN(VersionNumber::SPIRV_1_1, "1.1", "SPIR-V 1.1"),
                clEnumValN(VersionNumber::SPIRV_1_2, "1.2", "SPIR-V 1.2"),
                clEnumValN(VersionNumber::SPIRV_1_3, "1.3", "SPIR-V 1.3"),
-               clEnumValN(VersionNumber::SPIRV_1_4, "1.4", "SPIR-V 1.4"),
-               clEnumValN(VersionNumber::SPIRV_1_5, "1.5", "SPIR-V 1.5"),
-               clEnumValN(VersionNumber::SPIRV_1_6, "1.6", "SPIR-V 1.6")),
+               clEnumValN(VersionNumber::SPIRV_1_4, "1.4", "SPIR-V 1.4")),
     cl::init(VersionNumber::MaximumVersion));
 
 static cl::list<std::string>
@@ -161,10 +159,6 @@ static cl::opt<bool>
                                 "for the translation from SPIR-V."),
                        cl::Hidden);
 
-static cl::opt<bool> SPIRVEmitFunctionPtrAddrSpace(
-    "spirv-emit-function-ptr-addr-space", cl::init(false),
-    cl::desc("Emit and consume CodeSectionINTEL for function pointers"));
-
 using SPIRV::ExtensionID;
 
 #ifdef _SPIRV_SUPPORT_TEXT_FMT
@@ -196,21 +190,11 @@ static cl::opt<bool>
     SPIRVMemToReg("spirv-mem2reg", cl::init(false),
                   cl::desc("LLVM/SPIR-V translation enable mem2reg"));
 
-static cl::opt<bool> SPIRVPreserveAuxData(
-    "spirv-preserve-auxdata", cl::init(false),
-    cl::desc("Preserve all auxiliary data, such as function attributes and metadata"));
-
 static cl::opt<bool> SpecConstInfo(
     "spec-const-info",
     cl::desc("Display id of constants available for specializaion and their "
              "size in bytes"));
 
-static cl::opt<bool>
-    SPIRVPrintReport("spirv-print-report", cl::init(false),
-                     cl::desc("Display general information about the module "
-                              "(capabilities, extensions, version, memory model"
-                              " and addressing model)"));
-
 static cl::opt<SPIRV::FPContractMode> FPCMode(
     "spirv-fp-contract", cl::desc("Set FP Contraction mode:"),
     cl::init(SPIRV::FPContractMode::On),
@@ -241,21 +225,7 @@ static cl::opt<SPIRV::DebugInfoEIS> DebugEIS(
         clEnumValN(SPIRV::DebugInfoEIS::OpenCL_DebugInfo_100, "ocl-100",
                    "Emit debug info compliant with the OpenCL.DebugInfo.100 "
                    "extended instruction set. This version of SPIR-V debug "
-                   "info format is compatible with the SPIRV-Tools"),
-        clEnumValN(
-            SPIRV::DebugInfoEIS::NonSemantic_Shader_DebugInfo_100,
-            "nonsemantic-shader-100",
-            "Emit debug info compliant with the "
-            "NonSemantic.Shader.DebugInfo.100 extended instruction set. This "
-            "version of SPIR-V debug info format is compatible with the rules "
-            "regarding non-semantic instruction sets."),
-        clEnumValN(
-            SPIRV::DebugInfoEIS::NonSemantic_Shader_DebugInfo_200,
-            "nonsemantic-shader-200",
-            "Emit debug info compliant with the "
-            "NonSemantic.Shader.DebugInfo.200 extended instruction set. This "
-            "version of SPIR-V debug info format is compatible with the rules "
-            "regarding non-semantic instruction sets.")));
+                   "info format is compatible with the SPIRV-Tools")));
 
 static cl::opt<bool> SPIRVReplaceLLVMFmulAddWithOpenCLMad(
     "spirv-replace-fmuladd-with-ocl-mad",
@@ -263,68 +233,6 @@ static cl::opt<bool> SPIRVReplaceLLVMFmulAddWithOpenCLMad(
              "instruction from OpenCL extended instruction set"),
     cl::init(true));
 
-static cl::opt<SPIRV::BuiltinFormat> SPIRVBuiltinFormat(
-    "spirv-builtin-format",
-    cl::desc("Set LLVM-IR representation of SPIR-V builtin variables:"),
-    cl::init(SPIRV::BuiltinFormat::Function),
-    cl::values(
-        clEnumValN(SPIRV::BuiltinFormat::Function, "function",
-                   "Use functions to represent SPIR-V builtin variables"),
-        clEnumValN(SPIRV::BuiltinFormat::Global, "global",
-                   "Use globals to represent SPIR-V builtin variables")));
-static cl::opt<uint32_t> FnVarCategory(
-    "fnvar-category",
-    cl::desc("Specify architecture category of the target device (omitting "
-             "this flag denotes that the target device can be of any "
-             "category). Used only with -r and --fnvar-spec-enable."),
-    cl::value_desc("category"), cl::ValueRequired);
-
-static cl::opt<uint32_t> FnVarFamily(
-    "fnvar-family",
-    cl::desc("Specify architecture family of the target device (omitting this "
-             "flag denotes that the target device can be of any family). Used "
-             "only with -r and --fnvar-spec-enable."),
-    cl::value_desc("family"), cl::ValueRequired);
-
-static cl::opt<uint32_t> FnVarArch(
-    "fnvar-arch",
-    cl::desc("Specify architecture of the target device (omitting this flag "
-             "denotes that the target device can be of any architecture). Used "
-             "only with -r and --fnvar-spec-enable."),
-    cl::value_desc("architecture"), cl::ValueRequired);
-
-static cl::opt<uint32_t>
-    FnVarTarget("fnvar-target",
-                cl::desc("Specify target of the target device (omitting this "
-                         "flag denotes that the target device can be any "
-                         "target). Used only with -r and --fnvar-spec-enable."),
-                cl::value_desc("target"), cl::ValueRequired);
-
-static cl::list<uint32_t> FnVarFeatures(
-    "fnvar-features", cl::CommaSeparated,
-    cl::desc("Specify features of the target device (omitting this flag "
-             "denotes that the target device supports all features). Used only "
-             "with -r and --fnvar-spec-enable."),
-    cl::value_desc("feature0,feature1,..."), cl::ValueRequired);
-
-static cl::list<uint32_t> FnVarCapabilities(
-    "fnvar-capabilities", cl::CommaSeparated,
-    cl::desc("Specify capabilities of the target device (omitting this flag "
-             "denotes that the target device supports all features). Used only "
-             "with -r and --fnvar-spec-enable."),
-    cl::value_desc("capability0,capability1,..."), cl::ValueRequired);
-
-static cl::opt<std::string> FnVarSpvOut(
-    "fnvar-spv-out",
-    cl::desc("Save the specialized target-specific SPIR-V module to this file. "
-             "Used only with -r and --fnvar-spec-enable."),
-    cl::value_desc("file"), cl::ValueRequired);
-
-static cl::opt<bool> FnVarSpecEnable(
-    "fnvar-spec-enable", cl::init(false),
-    cl::desc("Enable specialization of function variants according to "
-             "SPV_INTEL_function_variants. Requires -r flag."));
-
 static std::string removeExt(const std::string &FileName) {
   size_t Pos = FileName.find_last_of(".");
   if (Pos != std::string::npos)
@@ -574,11 +482,8 @@ static int parseSPVExtOption(
   //  - during SPIR-V generation, assume that any known extension is disallowed.
   //  - during conversion to/from SPIR-V text representation, assume that any
   //    known extension is allowed.
-  llvm::Optional<bool> DefaultVal;
-  if (IsReverse)
-    DefaultVal = true;
   for (const auto &It : ExtensionNamesMap)
-    ExtensionsStatus[It.second] = DefaultVal;
+    ExtensionsStatus[It.second] = IsReverse;
 
   if (SPVExt.empty())
     return 0; // Nothing to do
@@ -771,15 +676,6 @@ int main(int Ac, char **Av) {
 
   Opts.setFPContractMode(FPCMode);
 
-  if (SPIRVBuiltinFormat.getNumOccurrences() != 0) {
-    if (!IsReverse) {
-      errs() << "Note: --spirv-builtin-format option ignored as it only "
-                "affects translation from SPIR-V to LLVM IR";
-    } else {
-      Opts.setBuiltinFormat(SPIRVBuiltinFormat);
-    }
-  }
-
   if (SPIRVMemToReg)
     Opts.setMemToRegEnabled(SPIRVMemToReg);
   if (SPIRVGenKernelArgNameMD)
@@ -789,14 +685,6 @@ int main(int Ac, char **Av) {
       return -1;
   }
 
-  if (SPIRVPreserveAuxData) {
-    Opts.setPreserveAuxData(
-        SPIRVPreserveAuxData);
-    if (!IsReverse)
-      Opts.setAllowedToUseExtension(
-          SPIRV::ExtensionID::SPV_KHR_non_semantic_info);
-  }
-
   if (SPIRVAllowUnknownIntrinsics.getNumOccurrences() != 0) {
     if (IsReverse) {
       errs()
@@ -827,74 +715,12 @@ int main(int Ac, char **Av) {
                 "affects translation from LLVM IR to SPIR-V";
     } else {
       Opts.setDebugInfoEIS(DebugEIS);
-      if (DebugEIS.getValue() ==
-          SPIRV::DebugInfoEIS::NonSemantic_Shader_DebugInfo_200)
-        Opts.setAllowExtraDIExpressionsEnabled(true);
-      if (DebugEIS.getValue() ==
-          SPIRV::DebugInfoEIS::NonSemantic_Shader_DebugInfo_100 ||
-          DebugEIS.getValue() ==
-          SPIRV::DebugInfoEIS::NonSemantic_Shader_DebugInfo_200)
-        Opts.setAllowedToUseExtension(
-            SPIRV::ExtensionID::SPV_KHR_non_semantic_info);
     }
   }
 
   if (PreserveOCLKernelArgTypeMetadataThroughString.getNumOccurrences() != 0)
     Opts.setPreserveOCLKernelArgTypeMetadataThroughString(true);
 
-  if (SPIRVEmitFunctionPtrAddrSpace.getNumOccurrences() != 0)
-    Opts.setEmitFunctionPtrAddrSpace(true);
-
-  Opts.setFnVarSpecEnable(FnVarSpecEnable);
-
-  if (!IsReverse &&
-      (FnVarSpecEnable || FnVarCategory != 0 || FnVarFamily != 0 ||
-       FnVarArch != 0 || FnVarTarget != 0 || !FnVarFeatures.empty() ||
-       !FnVarCapabilities.empty() || !FnVarSpvOut.empty())) {
-    errs() << "--fnvar-xxx flags can be used only with -r\n";
-    return -1;
-  }
-
-  if (!FnVarSpecEnable &&
-      (FnVarCategory != 0 || FnVarFamily != 0 || FnVarArch != 0 ||
-       FnVarTarget != 0 || !FnVarFeatures.empty() ||
-       !FnVarCapabilities.empty() || !FnVarSpvOut.empty())) {
-    errs() << "--fnvar-xxx flags need to be enabled with --fnvar-spec-enable\n";
-    return -1;
-  }
-
-  if (FnVarCategory.getNumOccurrences() > 0) {
-    Opts.setFnVarCategory(FnVarCategory);
-  }
-
-  if (FnVarFamily.getNumOccurrences() > 0) {
-    Opts.setFnVarFamily(FnVarFamily);
-  }
-
-  if (FnVarArch.getNumOccurrences() > 0) {
-    Opts.setFnVarArch(FnVarArch);
-  }
-
-  if (FnVarTarget.getNumOccurrences() > 0) {
-    Opts.setFnVarTarget(FnVarTarget);
-  }
-
-  if (!FnVarFeatures.empty()) {
-    Opts.setFnVarFeatures(FnVarFeatures);
-  }
-
-  if (!FnVarCapabilities.empty()) {
-    Opts.setFnVarCapabilities(FnVarCapabilities);
-  }
-
-  if (!FnVarSpvOut.empty()) {
-    Opts.setFnVarSpvOut(FnVarSpvOut);
-  }
-
-  if (!Opts.validateFnVarOpts()) {
-    return -1;
-  }
-
 #ifdef _SPIRV_SUPPORT_TEXT_FMT
   if (ToText && (ToBinary || IsReverse || IsRegularization)) {
     errs() << "Cannot use -to-text with -to-binary, -r, -s\n";
@@ -910,7 +736,7 @@ int main(int Ac, char **Av) {
     return convertSPIRV();
 #endif
 
-  if (!IsReverse && !IsRegularization && !SpecConstInfo && !SPIRVPrintReport)
+  if (!IsReverse && !IsRegularization && !SpecConstInfo)
     return convertLLVMToSPIRV(Opts);
 
   if (IsReverse && IsRegularization) {
@@ -936,39 +762,5 @@ int main(int Ac, char **Av) {
       std::cout << "Spec const id = " << SpecConst.first
                 << ", size in bytes = " << SpecConst.second << "\n";
   }
-
-  if (SPIRVPrintReport) {
-    std::ifstream IFS(InputFile, std::ios::binary);
-    int ErrCode = 0;
-    llvm::Optional<SPIRV::SPIRVModuleReport> BinReport =
-        SPIRV::getSpirvReport(IFS, ErrCode);
-    if (!BinReport) {
-      std::cerr << "Invalid SPIR-V binary, error code is " << ErrCode << "\n";
-      return -1;
-    }
-
-    SPIRV::SPIRVModuleTextReport TextReport =
-        SPIRV::formatSpirvReport(BinReport.value());
-
-    std::cout << "SPIR-V module report:"
-              << "\n Version: " << TextReport.Version
-              << "\n Memory model: " << TextReport.MemoryModel
-              << "\n Addressing model: " << TextReport.AddrModel << "\n";
-
-    std::cout << " Number of capabilities: " << TextReport.Capabilities.size()
-              << "\n";
-    for (auto &Capability : TextReport.Capabilities)
-      std::cout << "  Capability: " << Capability << "\n";
-
-    std::cout << " Number of extensions: " << TextReport.Extensions.size()
-              << "\n";
-    for (auto &Extension : TextReport.Extensions)
-      std::cout << "  Extension: " << Extension << "\n";
-
-    std::cout << " Number of extended instruction sets: "
-              << TextReport.ExtendedInstructionSets.size() << "\n";
-    for (auto &ExtendedInstructionSet : TextReport.ExtendedInstructionSets)
-      std::cout << "  Extended Instruction Set: " << ExtendedInstructionSet << "\n";
-  }
   return 0;
 }
